@@ -16,7 +16,5 @@ from .icecream import *  # noqa
 from .builtins import install, uninstall
 
 # Import all variables in __version__.py without explicit imports.
-meta = {}
-with open(pjoin(dirname(__file__), '__version__.py')) as f:
-    exec(f.read(), meta)
-globals().update(dict((k, v) for k, v in meta.items() if k not in globals()))
+from . import __version__
+globals().update(dict((k, v) for k, v in __version__.__dict__.items()))
